@@ -1,4 +1,4 @@
-//$Id: add-resource.cc,v 1.14 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.cc,v 1.15 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,16 +28,16 @@
 
 using namespace Guikachu;
 
-GUI::AddResourceWin::AddResourceWin ()
+GUI::AddResourceWin::AddResourceWin (ResourceManager *manager_):
+    gui (glade_xml_new (GUIKACHU_GLADEDIR "/guikachu.glade", "dlg_add")),
+    dialog (Gtk::wrap (GNOME_DIALOG (glade_xml_get_widget (gui, "dlg_add")))),
+    entry (Gtk::wrap (GTK_ENTRY (glade_xml_get_widget (gui, "add_name")))),
+    manager (manager_)
 {
-    gui = glade_xml_new (GUIKACHU_GLADEDIR "/guikachu.glade", "dlg_add");
-
     Gtk::OptionMenu *optmenu;
     Gtk::Menu       *menu;
     
-    dialog = Gtk::wrap (GNOME_DIALOG (glade_xml_get_widget (gui, "dlg_add")));
     optmenu = Gtk::wrap (GTK_OPTION_MENU (glade_xml_get_widget (gui, "add_type")));
-    entry = Gtk::wrap (GTK_ENTRY (glade_xml_get_widget (gui, "add_name")));
 
     menu = optmenu->get_menu ();
     menu->items ().clear ();
@@ -95,7 +95,7 @@ void GUI::AddResourceWin::run ()
     if (dialog_result != -1)
     {
 	if (dialog_result == 0)
-	    ResourceManager::create_resource (res_type, entry->get_text ());
+	    manager->create_resource (res_type, entry->get_text ());
     }
 }
 
