@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.15 2002/01/09 17:26:41 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.16 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,7 +49,7 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif    
 
-    Target *target = ResourceManager::get_target ();
+    Target *target = res->get_manager ()->get_target ();
 
     proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
@@ -68,7 +68,8 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     proptable->add (_("Vendor _ID:"), *manage (control));
 
     /* Target machine */
-    GUI::PropertyEditors::TargetCombo *target_combo = new GUI::PropertyEditors::TargetCombo;
+    GUI::PropertyEditors::TargetCombo *target_combo =
+	new GUI::PropertyEditors::TargetCombo (res->get_manager ());
     target_combo->stock_selected.connect (SigC::slot (this, &AppWindow::stock_target_cb));
     target_combo->custom_selected.connect (SigC::slot (this, &AppWindow::custom_target_cb));
 	
