@@ -1,4 +1,4 @@
-//$Id: blob-res.h,v 1.6 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: blob-res.h,v 1.9 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,18 +42,14 @@ namespace Guikachu
 	{
 	    GUI::BlobWindow *gui;
 	public:
-	    Blob (const std::string& id);
+	    Blob (ResourceManager   *owner,
+		  const std::string &id);
 	    virtual ~Blob ();
 
 	    virtual Type get_type () const { return RESOURCE_BLOB; };
 	    virtual void show_ui ();
 
 	    Property<std::string> contents;
-
-	private:
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
