@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.12 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.16 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,15 +24,6 @@ namespace Guikachu
     namespace Resources
     {
 	class Dialog;
-
-	enum DialogType
-	{
-	    DIALOG_INFORMATION,
-	    DIALOG_CONFIRMATION,
-	    DIALOG_WARNING,
-	    DIALOG_ERROR
-	};
-	    
     }
 }
 
@@ -54,7 +45,16 @@ namespace Guikachu
 	{
 	    Guikachu::GUI::DialogWindow *gui;
 	public:
-	    Dialog (const std::string& id);
+	    enum DialogType
+	    {
+		TYPE_INFORMATION,
+		TYPE_CONFIRMATION,
+		TYPE_WARNING,
+		TYPE_ERROR
+	    };
+	    
+	    Dialog (ResourceManager   *owner,
+		    const std::string &id);
 	    virtual ~Dialog ();
 	    
 	    virtual Type get_type () const { return RESOURCE_DIALOG; };
@@ -66,11 +66,6 @@ namespace Guikachu
 	    Property<std::vector<std::string> > buttons;
 	    Property<unsigned int>              default_button;
 	    Properties::ResourceRef             help_id;
-	    
-	private:
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
