@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.25 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.27 2002/06/07 23:40:18 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -182,12 +182,12 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
 		Gtk::Menu_Helpers::MenuElem (				\
 		    s,							\
 		    bind (slot (this, &DialogWindow::type_menu_cb),	\
-			  Resources::t)));
+			  Resources::Dialog::t)));
 
-    DIALOG_TYPE (_("Information"),  DIALOG_INFORMATION);
-    DIALOG_TYPE (_("Confirmation"), DIALOG_CONFIRMATION);
-    DIALOG_TYPE (_("Warning"),      DIALOG_WARNING);
-    DIALOG_TYPE (_("Error"),        DIALOG_ERROR);
+    DIALOG_TYPE (_("Information"),  TYPE_INFORMATION);
+    DIALOG_TYPE (_("Confirmation"), TYPE_CONFIRMATION);
+    DIALOG_TYPE (_("Warning"),      TYPE_WARNING);
+    DIALOG_TYPE (_("Error"),        TYPE_ERROR);
 
 #undef DIALOG_TYPE
     
@@ -197,7 +197,9 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
 		    _("An icon will be included in the dialog, based on its type"));
     
     /* Help ID */
-    control = new GUI::PropertyEditors::ResourceCombo (Resources::RESOURCE_STRING, res->help_id);
+    control = new GUI::PropertyEditors::ResourceCombo (res->get_manager (),
+						       Resources::RESOURCE_STRING,
+						       res->help_id);
     proptable->add (_("_Help ID:"), *manage (control));
 
     /* Text */
@@ -243,7 +245,7 @@ void GUI::DialogWindow::update ()
     update_block = false;
 }
 
-void GUI::DialogWindow::type_menu_cb (Resources::DialogType type)
+void GUI::DialogWindow::type_menu_cb (Resources::Dialog::DialogType type)
 {
     res->dialog_type = type;
 }
