@@ -1,4 +1,4 @@
-//$Id: button-canvas.h,v 1.8 2002/01/28 18:21:58 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.h,v 1.9 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,9 @@
 #include "widget-canvas.h"
 #include "resizeable-canvas.h"
 
+#include <gnome--/canvas-item.h>
+#include <gnome--/canvas-polygon.h>
+
 namespace Guikachu
 {
     namespace GUI
