@@ -1,4 +1,4 @@
-//$Id: font.cc,v 1.14 2002/05/05 13:19:50 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.18 2002/06/29 22:13:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,7 +18,7 @@
 
 #include "font.h"
 
-#include <strstream>
+#include <sstream>
 #include <fstream>
 #include <stdio.h> /* For sscanf */
 #include <list>
@@ -59,9 +59,8 @@ static char next_char (const std::string &text,
 	i++;
 	return '\x0a';
     case 'r':
-	// FIXME: Inline newlines don't work ATM
 	i++;
-	return '\x00';
+	return '\r';
     case 't':
 	i++;
 	return '\x09';
@@ -128,18 +127,28 @@ static char next_char (const std::string &text,
     // Unknown escape sequence: return escaped character
     return *(i++);
 }
+
+void set_pixel (guint8          *pixel,
+		const Gdk_Color &color)
+{
+    pixel[0] = color.red   >> 8;
+    pixel[1] = color.green >> 8;
+    pixel[2] = color.blue  >> 8;
+    pixel[3] = 255;
 }
+
+} // Anonymous namespace
     
 using namespace Guikachu::GUI::FormEditor;
 
 Font::Font (const std::string &filename):
-    height (0)
+    line_height (0)
 {
     parse (filename);
 }
 
 Font::Font ():
-    height (0)
+    line_height (0)
 {
 }
 
@@ -165,13 +174,14 @@ void Font::parse (std::istream &stream)
 	if (curr_line == "")
 	    continue;
 	
-	std::strstream curr_line_stream;
-	std::string    param_name;
-	int            param_val;
+	std::stringstream curr_line_stream;
+	std::string       param_name;
+	int               param_val;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
-	curr_line_stream >> param_val;
+	if (!(curr_line_stream >> param_val))
+	    param_val = 0;
 
 	if (param_name == "ascent")
 	    ascent = param_val;
@@ -188,8 +198,8 @@ void Font::parse (std::istream &stream)
 
     while (!stream.eof ())
     {
-	std::strstream curr_line_stream;
-	std::string    param_name;
+	std::stringstream curr_line_stream;
+	std::string       param_name;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
@@ -198,8 +208,9 @@ void Font::parse (std::istream &stream)
 	{
 	    std::string glyph_index;
 	    char        glyph_char;
-	    
-	    curr_line_stream >> glyph_index;
+
+	    if (!(curr_line_stream >> glyph_index))
+		glyph_index = "\\0";
 
 	    /* Un-escape char index */
             if (glyph_index[0] == '\'')
@@ -210,7 +221,7 @@ void Font::parse (std::istream &stream)
             }
 
 	    /* Parse current glyph */
-	    Glyph curr_glyph (stream, height);
+	    Glyph curr_glyph (stream, line_height);
 
 	    glyphs.insert (std::pair <char, Glyph> (glyph_char, curr_glyph));
 	}
@@ -219,9 +230,9 @@ void Font::parse (std::istream &stream)
     }
 }
 
-static void free_pixdata_delete (guchar *pixels, gpointer data)
+static void free_pixdata_gfree (guint8 *pixels, gpointer data)
 {
-    delete pixels;
+    g_free (pixels);
 }
 
 const Glyph& Font::get_glyph (char c) const
@@ -230,7 +241,7 @@ const Glyph& Font::get_glyph (char c) const
     if (found_glyph != glyphs.end ())
 	return found_glyph->second;
 
-    static Glyph empty_glyph (height, ascent);
+    static Glyph empty_glyph (line_height, ascent);
 
     return empty_glyph;
 }
@@ -240,70 +251,79 @@ GdkPixbuf* Font::render (const std::string &text,
 {
     if (text == "")
 	return 0;
-    
-    std::list <Glyph> typeset;
-    int width = 0;
 
+    int width = 0;
+    int height = line_height;
+    std::list<Glyph> typeset;
+    
     std::string::const_iterator i = text.begin ();
     while (i != text.end ())
     {
 	char c = next_char (text, i);
 	const Glyph &g = get_glyph (c);
-
+	
 	typeset.push_back (g);
 	width += g.width;
     }
 
-#if 0
-    /* HACK: If there are no displayable characters, return a 
-     * blank1 x height pixmap
-     */
-    if (width == 0) 
-    {
-	guint32 *pixbuf_data = new guint32[height];
-	
-	for (unsigned int y = 0; y < height; y++)
-	    pixbuf_data[y] = 0;
-	
-	return gdk_pixbuf_new_from_data ((guchar *) pixbuf_data,
-					 GDK_COLORSPACE_RGB,
-					 true,
-					 8,
-					 1, height,
-					 4,
-					 free_pixdata_delete, 0);
-    }
-#endif
+    guint8 *pixbuf_data = g_new0 (guint8, width * height * 4);
+    render_raw_line (typeset, color, pixbuf_data, width * 4);
     
-    guchar *pixbuf_data = new guchar[width * height * 4];
-    int x_position = 0;
+    return gdk_pixbuf_new_from_data (pixbuf_data,
+				     GDK_COLORSPACE_RGB,
+				     true,
+				     8,
+				     width, height,
+				     width * 4,
+				     free_pixdata_gfree, 0);
+}
 
-    for (std::list<Glyph>::const_iterator i = typeset.begin ();
-         i != typeset.end (); i++)
+GdkPixbuf* Font::render_multi_line (const std::string &text,
+				    const Gdk_Color   &color) const
+{
+    if (text == "")
+	return 0;
+
+    std::list <std::list <Glyph> > typeset;
+    int width = 0;
+    int height = 0;
+
+    int current_width = 0;
+    std::list <Glyph> current_typeset;
+    
+    std::string::const_iterator i = text.begin ();
+    while (i != text.end ())
     {
-        const Glyph &glyph = *i;
+	char c = next_char (text, i);
+	if (c != '\r')
+	{
+	    const Glyph &g = get_glyph (c);
+	    
+	    current_typeset.push_back (g);
+	    current_width += g.width;
+	} else {
+	    typeset.push_back (current_typeset);
+	    current_typeset.clear ();
 
-        unsigned int curr_width = glyph.width;
-        bool **curr_bitmap = glyph.bitmap;
-        
-        for (unsigned int y = 0; y < height; y++)
-        {
-            for (unsigned int x = 0; x < curr_width; x++)
-            {
-                if (curr_bitmap[y][x])
-                {
-                    pixbuf_data[((y * width) + x_position + x) * 4 + 0] = color.red >> 8;
-                    pixbuf_data[((y * width) + x_position + x) * 4 + 1] = color.green >> 8;
-                    pixbuf_data[((y * width) + x_position + x) * 4 + 2] = color.blue >> 8;
-                    pixbuf_data[((y * width) + x_position + x) * 4 + 3] = 255;
-                } else {
-                    pixbuf_data[((y * width) + x_position + x) * 4 + 3] = 0;
-                }
-            }
+	    width = std::max<int> (width, current_width);
+	    current_width = 0;
+	    height += line_height;
 	}
+    }
+    // Add last line
+    typeset.push_back (current_typeset);
+    width = std::max<int> (width, current_width);
+    height += line_height;
+    
+    guint8 *pixbuf_data = g_new0 (guint8, width * height * 4);
 
-	x_position += curr_width;
+    int offset = 0;
+    for (std::list <std::list <Glyph> >::const_iterator i = typeset.begin ();
+	 i != typeset.end (); i++)
+    {
+	render_raw_line (*i, color, pixbuf_data + offset, width * 4);
 
+	offset += (line_height * width) * 4;
     }
     
     return gdk_pixbuf_new_from_data (pixbuf_data,
@@ -312,24 +332,97 @@ GdkPixbuf* Font::render (const std::string &text,
 				     8,
 				     width, height,
 				     width * 4,
-				     free_pixdata_delete, 0);
+				     free_pixdata_gfree, 0);
 }
 
-unsigned int Font::string_width (const std::string &text) const
+void Font::render_raw_line (const std::list<Glyph> &typeset,
+			    const Gdk_Color        &color,
+			    guint8                 *target,
+			    int                     target_rowstride) const
+{
+    for (std::list<Glyph>::const_iterator i = typeset.begin ();
+         i != typeset.end (); i++)
+    {
+        const Glyph &glyph = *i;
+
+        bool **curr_bitmap = glyph.bitmap;
+	guint8 *curr_row = target;
+	
+        for (int y = 0; y < line_height; y++)
+        {
+	    guint8 *curr_pixel = curr_row;
+	    
+            for (int x = 0; x < glyph.width; x++)
+            {
+                if (curr_bitmap[y][x])
+		    set_pixel (curr_pixel, color);
+
+		curr_pixel += 4;
+	    }
+
+	    curr_row += target_rowstride;
+	}
+
+	target += glyph.width * 4;
+    }
+}
+
+int Font::get_line_width (const std::string &text) const
 {
-    if (text == "")
-	return 0;
-    
     int width = 0;
-    
+
     std::string::const_iterator i = text.begin ();
     while (i != text.end ())
     {
 	char c = next_char (text, i);
 	const Glyph &g = get_glyph (c);
-
+	
 	width += g.width;
     }
-
+    
     return width;
 }
+
+int Font::get_raw_line_width (const std::string &text) const
+{
+    int width = 0;
+    
+    for (std::string::const_iterator i = text.begin ();
+	 i != text.end (); i++)
+    {
+	const Glyph &g = get_glyph (*i);
+	
+	width += g.width;
+    }
+    
+    return width;
+}
+
+void Font::get_text_extents (const std::string &text,
+			     int               &width,
+			     int               &height) const
+{
+    width = 0;
+    height = line_height; // Even if the string is empty, a height of
+                          // at least one line is returned
+    
+    std::string::const_iterator i = text.begin ();
+    std::string current_line;
+    while (i != text.end ())
+    {
+	char c = next_char (text, i);
+
+	if (c != '\r')
+	    current_line += c;
+	else
+	{
+	    width = std::max<int> (width, get_raw_line_width (current_line));
+	    height += line_height;
+	    current_line.clear ();
+	}
+    }
+
+    // Add last line
+    width = std::max<int> (width, get_raw_line_width (current_line));
+    height += line_height;
+}
