@@ -1,4 +1,4 @@
-//$Id: font.h,v 1.7 2002/01/12 14:12:03 cactus Exp $ -*- c++ -*-
+//$Id: font.h,v 1.9 2002/05/30 19:00:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <string>
 #include <iostream>
 #include "hash-map.h"
+#include <list>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk--/color.h>
@@ -34,18 +35,18 @@ namespace Guikachu
 	{
 	    struct Glyph
 	    {
-		unsigned int   width;
-		int            offset;
-		bool         **bitmap;
+		int    width;
+		int    offset;
+		bool **bitmap;
 	    public:
-		Glyph (std::istream &stream, unsigned int &height);
-		Glyph (unsigned int height, unsigned int ascent); // Create placeholder glyph
+		Glyph (std::istream &stream, int &height);
+		Glyph (int height, int ascent); // Create placeholder glyph
 	    };
 	    
 	    class Font
 	    {
 		std::hash_map <char, Glyph> glyphs;
-		unsigned int                height, ascent, descent;
+		int                         line_height, ascent, descent;
 		
 	    public:
 		Font (const std::string &filename);
@@ -54,17 +55,34 @@ namespace Guikachu
 		void parse (const std::string &filename);
 		void parse (std::istream      &stream);
 
-		GdkPixbuf* render (const std::string &text,
-				   const Gdk_Color   &color) const;
-
-		unsigned int string_width (const std::string& text) const;
 		
-		int get_height  () const { return height; };
-		int get_ascent  () const { return ascent; };
-		int get_descent () const { return descent; };
+		GdkPixbuf* render            (const std::string &text,
+				              const Gdk_Color   &color) const;
+		
+		GdkPixbuf* render_multi_line (const std::string &text,
+					      const Gdk_Color   &color) const;
+
+		
+		void get_text_extents (const std::string &text,
+				       int               &width,
+				       int               &height) const;
+
+
+		int get_line_width   (const std::string &text) const;
+		
+		int get_line_height  () const { return line_height; };
+		int get_ascent       () const { return ascent;      };
+		int get_descent      () const { return descent;     };
 
 	    private:
 		const Glyph& get_glyph (char c) const;
+		
+		void render_raw_line (const std::list<Glyph> &typeset,
+				      const Gdk_Color        &color,
+				      guint8                 *target,
+				      int                     target_rowstride) const;
+
+		int get_raw_line_width (const std::string &text) const;
 	    };
 	}
     }
