@@ -1,4 +1,4 @@
-//$Id: list.h,v 1.13 2002/02/23 20:37:11 cactus Exp $ -*- c++ -*-
+//$Id: list.h,v 1.16 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -60,16 +60,10 @@ namespace Guikachu
 	    Property<bool>                      usable;
 	    Property<std::vector<std::string> > items;
 
-	    int get_display_height () const;
+	    int get_height () const;
 
 	protected:
 	    int get_auto_width () const;
-
-	private:
-	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     }
 }
