@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.cc,v 1.19 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.cc,v 1.21 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,8 +42,8 @@ void PushButtonCanvasItem::update ()
 
     group = new Gnome::CanvasGroup (*draw_group, 0, 0);
     
-    int width = widget->get_display_width ();
-    int height = widget->get_display_height ();
+    int width = widget->get_width ();
+    int height = widget->get_height ();
 
     /* Don't ask about the +1, I have no idea... */
     int x1 = widget->x - 1;
@@ -67,6 +67,7 @@ void PushButtonCanvasItem::update ()
 	       widget->text, widget->font,
 	       text_x, text_y,
 	       widget->usable,
+	       false,
 	       GTK_ANCHOR_CENTER,
 	       width, height);
 
@@ -77,7 +78,7 @@ void PushButtonCanvasItem::get_bounds (int &x1, int &y1,
 				       int &x2, int &y2)
 {
     x1 = widget->x + 1;
-    x2 = x1 + widget->get_display_width () - 3;
+    x2 = x1 + widget->get_width () - 3;
     y1 = widget->y + 1;
-    y2 = y1 + widget->get_display_height () - 1;
+    y2 = y1 + widget->get_height () - 1;
 }
