@@ -1,4 +1,4 @@
-//$Id: resizeable-prop.cc,v 1.10 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
+//$Id: resizeable-prop.cc,v 1.11 2002/06/02 13:53:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,7 @@ void ResizeableProperties::add_width_controls (Widgets::Resizeable *res,
     Gtk::Widget *control;
     
     /* Width */
-    control = new GUI::PropertyEditors::WidthEntry (res->width);
+    control = new GUI::PropertyEditors::WidthEntry (res->get_manager (), res->width);
     proptable.add (_("_Width:"), *manage (control),
 		   _("Horizontal size of the widget"));    
 }
@@ -42,7 +42,7 @@ void ResizeableProperties::add_height_controls (Widgets::Resizeable *res,
     Gtk::Widget *control;
     
     /* Height */
-    control = new GUI::PropertyEditors::HeightEntry (res->height);
+    control = new GUI::PropertyEditors::HeightEntry (res->get_manager (), res->height);
     proptable.add (_("_Height:"), *manage (control),
 		   _("Vertical size of the widget"));
     
