@@ -1,4 +1,4 @@
-//$Id: resizeable.h,v 1.10 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
+//$Id: resizeable.h,v 1.11 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -37,8 +37,8 @@ namespace Guikachu
 	public:
 	    virtual ~Resizeable () {};
 	    
-	    virtual int get_display_width  () const;
-	    virtual int get_display_height () const;
+	    virtual int get_width  () const;
+	    virtual int get_height () const;
 
 	    Property<int> &width;
 	    Property<int> &height;
