@@ -1,4 +1,4 @@
-//$Id: scrollbar-canvas.cc,v 1.17 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-canvas.cc,v 1.18 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,7 +51,7 @@ void ScrollBarCanvasItem::update ()
 
     group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
-    int width = widget->get_display_width ();
+    int width = widget->get_width ();
     int height = widget->height;
 
     int x1 = widget->x;
