@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.cc,v 1.10 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.cc,v 1.11 2002/06/02 13:53:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -77,14 +77,14 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     
     /* Size */
     /* Width */
-    control = new GUI::PropertyEditors::WidthEntry (res->width);
+    control = new GUI::PropertyEditors::WidthEntry (res->get_manager (), res->width);
     control = new GUI::PropertyEditors::AutoToggle (*manage (control), res->manual_width);
     proptable->add (_("_Width:"), *manage (control),
 		    _("Horizontal size of the widget "
 		      "(check to set manually)"));
 
     /* Height */
-    control = new GUI::PropertyEditors::HeightEntry (res->height);
+    control = new GUI::PropertyEditors::HeightEntry (res->get_manager (), res->height);
     proptable->add (_("_Height:"), *manage (control),
 		    _("Vertical size of the widget"));
     
