@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.12 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.15 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,12 +57,6 @@ namespace Guikachu
 	protected:
 	    int get_auto_width () const;
 
-	private:
-	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
-
 	private:
 	    void update ();
 	};
