@@ -1,4 +1,4 @@
-//$Id: selector-trigger.h,v 1.13 2002/01/26 00:19:17 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.16 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -58,14 +58,8 @@ namespace Guikachu
 	    Property<bool>   anchor_right;
 
 	protected:
-	    virtual int get_auto_width  () const;
-	    virtual int get_auto_height () const;
-
-	private:
-	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
+	    int get_auto_width  () const;
+	    int get_auto_height () const;
 	};
     }
 }
