@@ -1,4 +1,4 @@
-//$Id: table-prop.cc,v 1.8 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: table-prop.cc,v 1.9 2002/06/02 13:53:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -217,7 +217,8 @@ void TableColEditor::update ()
 			     0, 0);
 	    g_free (buffer);
 	    
-	    adj = new Gtk::Adjustment (columns[i], 1, GUIKACHU_SCREEN_WIDTH);
+	    adj = new Gtk::Adjustment (columns[i],
+				       1, table->get_manager()->get_target ()->screen_width);
 	    adj->value_changed.connect (
 		SigC::bind (SigC::slot (this, &TableColEditor::col_width_cb), i));
 	    spinbutton = new Gtk::SpinButton (*manage (adj));
