@@ -1,4 +1,4 @@
-//$Id: table.h,v 1.9 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: table.h,v 1.13 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,23 +45,22 @@ namespace Guikachu
 	public:
 	    Table (Resources::Form   *owner,
 		   const std::string &id);
-	    virtual ~Table ();
+	    ~Table ();
 	    
-	    virtual Type get_type () const { return WIDGET_TABLE; };
+	    Type get_type () const { return WIDGET_TABLE; };
+
+	    // Implementation of FormElement methods
+	    int get_width  () const;
+	    int get_height () const;
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<int>               num_rows;
 	    Property<int>               num_columns;
 	    Property<std::vector<int> > column_width;
 	    
 	private:
-	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
-
 	    void update ();
 	};
     }
