@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.cc,v 1.10 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.cc,v 1.12 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,10 +42,10 @@ void TextFieldCanvasItem::update ()
     group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     const Font &font = get_font (widget->font);
-    int height = widget->get_display_height ();
-    int width = widget->get_display_width ();
+    int height = widget->get_height ();
+    int width = widget->get_width ();
 
-    int line_height = font.get_height ();
+    int line_height = font.get_line_height ();
     int num_lines = 1;
     if (height > line_height && widget->multi_line)
 	num_lines = height / line_height;
@@ -101,7 +101,7 @@ void TextFieldCanvasItem::get_bounds (int &x1, int &y1,
 				      int &x2, int &y2)
 {
     x1 = widget->x;
-    x2 = x1 + widget->get_display_width ();
+    x2 = x1 + widget->get_width ();
     y1 = widget->y;
-    y2 = y1 + widget->get_display_height ();
+    y2 = y1 + widget->get_height ();
 }
