@@ -1,4 +1,4 @@
-//$Id: widget-canvas.cc,v 1.7 2002/02/05 21:34:24 cactus Exp $ -*- c++ -*-
+//$Id: widget-canvas.cc,v 1.8 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,8 +41,7 @@ WidgetCanvasItem::WidgetCanvasItem (Widget             *widget_,
     CanvasItem (widget_, parent_group_),
     widget (widget_),
     selected (false),
-    selection_box (0),
-    dirty (false)
+    selection_box (0)
 {
     // Chain signal callbacks
     canvas_item_changed.connect (SigC::slot (this, &WidgetCanvasItem::canvas_item_changed_cb));
@@ -58,7 +57,7 @@ WidgetCanvasItem::WidgetCanvasItem (Widget             *widget_,
     
     Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
     
-    widget->changed.connect  (SigC::slot (this, &WidgetCanvasItem::widget_changed_cb));
+    widget->changed.connect  (SigC::slot (this, &WidgetCanvasItem::update));
     widget->selected.connect (SigC::slot (this, &WidgetCanvasItem::widget_selected_cb));
 }
 
@@ -68,24 +67,6 @@ WidgetCanvasItem::~WidgetCanvasItem ()
 	delete selection_box;
 }
 
-void WidgetCanvasItem::widget_changed_cb ()
-{
-    if (!dirty)
-    {
-	dirty = true;
-	Gtk::Main::idle.connect (SigC::retbind (
-	    SigC::slot (this, &WidgetCanvasItem::idle_cb), 0));
-    }
-}
-
-void WidgetCanvasItem::idle_cb ()
-{
-    g_return_if_fail (dirty);
-
-    update ();
-    dirty = false;
-}
-
 void WidgetCanvasItem::canvas_item_changed_cb ()
 {
     item->event.connect (SigC::retbind (
