@@ -1,4 +1,4 @@
-//$Id: widget-prop.cc,v 1.5 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: widget-prop.cc,v 1.6 2002/06/02 13:53:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,13 +32,13 @@ void WidgetProperties::add_position_controls (Widget             *res,
     Gtk::Widget *control;
 
     /* X */
-    control = new GUI::PropertyEditors::XPosEntry (res->x);
+    control = new GUI::PropertyEditors::XPosEntry (res->get_manager (), res->x);
     proptable.add (_("_X:"), *manage (control),
 		   _("Horizontal position of the widget, relative "
 		     "to the parent form"));
 
     /* Y */
-    control = new GUI::PropertyEditors::YPosEntry (res->y);
+    control = new GUI::PropertyEditors::YPosEntry (res->get_manager (), res->y);
     proptable.add (_("_Y:"), *manage (control),
 		   _("Vertical position of the widget, relative "
 		     "to the parent form"));
