@@ -1,4 +1,4 @@
-//$Id: widget.h,v 1.32 2002/02/05 15:08:56 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.36 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,7 +49,6 @@ namespace Guikachu
 #include <iostream>
 #include <sigc++/basic_signal.h>
 
-#include "storage-node.h"
 #include "form-res.h"
 #include "form-editor/widget-canvas.h"
 #include "form-editor/form-element.h"
@@ -78,7 +77,7 @@ namespace Guikachu
 	virtual Widgets::Type get_type () const = 0;
 	
 	// Notification
-	SigC::Signal0<void> changed;
+	QueuedSignal changed;
 	
 	// Common properties
 	ID            id;
@@ -98,16 +97,9 @@ namespace Guikachu
 	virtual Gtk::Widget                       *create_editor      () = 0;
 	virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group) = 0;
 	
-	Resources::Form *get_form () const { return owner; };
-	
-    public:
-	// Persistance
-	virtual bool load (StorageNode &node) = 0;
-	virtual void save (StorageNode &node) const = 0;
-	virtual void save_rcp (std::ostream &ostr) const = 0;
+	Resources::Form *get_form    () const;
+	ResourceManager *get_manager () const;
     };
-    
-    std::ostream& operator<< (std::ostream &ostr, const Widget* res);
 }
 
 #endif /* !GUIKACHU_FORM_EDITOR_WIDGET_H */
