@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.23 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.26 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,7 +50,8 @@ namespace Guikachu
 	    std::set<Widget*> widgets;
 
 	public:
-	    Form (const std::string& name);
+	    Form (ResourceManager   *owner,
+		  const std::string &name);
 	    virtual ~Form ();
 	    
 	    virtual Type get_type () const { return RESOURCE_FORM; };
@@ -84,15 +85,9 @@ namespace Guikachu
 	    Property<int>           width;
 	    Property<int>           height;
 
-	private:
-	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
-
-	    Widget* load_widget (StorageNode &node);
-	    void    save_widget (StorageNode &node,
-				 Widget      *widget) const;
+	    // Utility functions for widgets
+	    int get_screen_width () const;
+	    int get_screen_height () const;
 	};
     };
 };
