@@ -1,4 +1,4 @@
-//$Id: form-win-selection.cc,v 1.2 2002/03/23 23:19:25 cactus Exp $ -*- c++ -*-
+//$Id: form-win-selection.cc,v 1.3 2002/05/01 21:02:29 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,23 +24,22 @@ void FormWindow::selection_add (Widget *widget)
 {
     selected_widgets.insert (widget);
     widget->selected (true);
+
+    if (last_widget != widget)
+    {
+	if (last_widget)
+	    last_widget->selected_last (false);
+	widget->selected_last (true);
+    }
 }
 
 void FormWindow::selection_remove (Widget *widget)
 {
-#if 0
-    if (selected_widgets.find (widget) == selected_widgets.end ())
-	return;
-#endif
-    
     selected_widgets.erase (widget);
     widget->selected (false);
 
     if (last_widget == widget)
-    {
 	last_widget->selected_last (false);
-	last_widget = 0;
-    }
 }
 
 void FormWindow::selection_toggle (Widget *widget)
@@ -58,10 +57,10 @@ void FormWindow::selection_clear ()
 	(*i)->selected (false);
 
     if (selected_widgets.find (last_widget) != selected_widgets.end ())
-    {
 	last_widget->selected_last (false);
-	last_widget = 0;
-    }
+
+    // FIXME: de-select form when clicking on background
+//    form_widget->selected_last (false);
     
     selected_widgets.clear ();
 }
@@ -90,11 +89,12 @@ void FormWindow::select_form ()
     show_form_property_editor ();
 }
 
-void FormWindow::widget_selected_last_cb (Widget *widget, bool selected)
+void FormWindow::widget_selected_last_cb (bool selected, Widget *widget)
 {
-    if (!selected)
-	return;
-    
+    if (selected)
+	last_widget = widget;
+    else
+	last_widget = 0;
 }
 
 void FormWindow::select_widget (Widget *widget)
@@ -110,7 +110,10 @@ void FormWindow::select_widget (Widget *widget)
     }
 
     top_treeitem->deselect ();
-    form_canvas_item->selected (false);
+
+    form_widget->selected (false);
+    form_widget->selected_last (false);
+    
     widget->request_edit ();
     
     if (!add_to_selection)
