@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.51 2002/05/01 21:02:29 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.53 2002/06/24 23:06:17 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -121,7 +121,8 @@ FormWindow::FormWindow (Form *res_):
 
     // Callbacks for global settings
     Preferences::FormEditor::colors_changed.connect (slot (this, &FormWindow::colors_changed_cb));
-    ResourceManager::get_target ()->changed.connect (slot (this, &FormWindow::target_changed_cb));
+    res->get_manager ()->get_target ()->changed.connect (
+	slot (this, &FormWindow::target_changed_cb));
     
     if (!palette)
 	palette = new Guikachu::GUI::Palette ();
@@ -181,19 +182,20 @@ void FormWindow::update ()
 }
 
 void FormWindow::recenter_canvas ()
-{
+{   
     float zoom_factor = canvas->get_pixels_per_unit ();
-    canvas->set_scroll_region (0, 0, GUIKACHU_SCREEN_WIDTH - 1,
-			       GUIKACHU_SCREEN_HEIGHT - 1);
-    canvas->set_usize (int(GUIKACHU_SCREEN_WIDTH * zoom_factor),
-		       int(GUIKACHU_SCREEN_HEIGHT * zoom_factor));
+    int screen_width = res->get_manager ()->get_target ()->screen_width;
+    int screen_height = res->get_manager ()->get_target ()->screen_height;
+    
+    canvas->set_scroll_region (0, 0, screen_width - 1, screen_height - 1);
+    canvas->set_usize (int (screen_width * zoom_factor),
+		       int (screen_height * zoom_factor));
 
     
     Gtk::ScrolledWindow *scrollwindow = Gtk::wrap (
 	GTK_SCROLLED_WINDOW (glade_xml_get_widget (gui, "form_scrollwin")));
     
-    scrollwindow->set_usize (GUIKACHU_SCREEN_WIDTH + 40,
-			     GUIKACHU_SCREEN_HEIGHT + 40);
+    scrollwindow->set_usize (screen_width + 40, screen_height + 40);
 }
 
 void FormWindow::force_canvas_update ()
@@ -347,14 +349,16 @@ void FormWindow::palette_cb (Widgets::Type type)
     // Create overlay canvas item
     Gnome::CanvasPoints   points;
 
-    int x = res->x;
-    int y = res->y;
+    int x1 = res->x;
+    int y1 = res->y;
+    int x2 = x1 + res->get_manager ()->get_target ()->screen_width;
+    int y2 = y1 + res->get_manager ()->get_target ()->screen_height;
     
-    points.push_back (Gnome::Art::Point (x, y));
-    points.push_back (Gnome::Art::Point (GUIKACHU_SCREEN_WIDTH + x, y));
-    points.push_back (Gnome::Art::Point (GUIKACHU_SCREEN_WIDTH + x, GUIKACHU_SCREEN_HEIGHT + y));
-    points.push_back (Gnome::Art::Point (x, GUIKACHU_SCREEN_HEIGHT + y));
-    points.push_back (Gnome::Art::Point (x, y));
+    points.push_back (Gnome::Art::Point (x1, y1));
+    points.push_back (Gnome::Art::Point (x2, y1));
+    points.push_back (Gnome::Art::Point (x2, y2));
+    points.push_back (Gnome::Art::Point (x1, y2));
+    points.push_back (Gnome::Art::Point (x1, y1));
     
     canvas_overlay = new Gnome::CanvasPolygon (*canvas->root (), points);
     canvas_overlay->event.connect (slot (this, &FormWindow::canvas_overlay_cb));
@@ -369,8 +373,8 @@ void FormWindow::add_widget (int x, int y)
     
     Widget *widget = res->create_widget (palette_selection);
 
-    widget->x = x;
-    widget->y = y;
+    widget->x = x - widget->get_width () / 2;
+    widget->y = y - widget->get_height () / 2;
 }
 
 void FormWindow::form_clicked_cb ()
