@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.18 2002/01/09 17:26:41 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.20 2002/06/23 15:45:29 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,19 +17,18 @@
  */
 
 #include "config.h"
+#include <libgnome/libgnome.h>
 
 #include <gnome--/main.h>
 #include <glade/glade.h>
-
 #include <fcntl.h>
 
 #ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
-#include "mainwin.h"
-#include "resource-manager.h"
 #include "session.h"
+#include "mainwin.h"
 
 namespace {
     enum FileType
@@ -154,11 +153,7 @@ int main (int argc, char **argv)
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/guikachu.png");
 #endif
     
-    GUI::MainWin main_win;
-    
-    const std::vector<std::string> &filenames = app.get_cmd_arguments ();
-    std::string filename = "";
-
+#if 0
     if (filenames.size ())
     {
 	for (std::vector<std::string>::const_iterator i = filenames.begin ();
@@ -181,7 +176,7 @@ int main (int argc, char **argv)
 	    main_win.set_filename (filename);
 	}
     }
+#endif
 
-    main_win.show_all ();
     app.run ();
 }
