@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.19.2.1 2002/05/25 13:34:47 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.24 2002/06/30 18:33:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,6 +26,8 @@
 #include <gnome--/main.h>
 #include <gnome--/messagebox.h>
 
+#include "io/rcp-save.h"
+
 #include "argumentsink.h"
 #include <sigc++/retbind.h>
 
@@ -64,7 +66,7 @@ static string time_ago_string (time_t ago)
 
 bool GUI::MainWin::check_save ()
 {
-    if (!ResourceManager::is_dirty ())
+    if (!manager->is_dirty ())
     {
 	if (in_exit)
 	    Gnome::Main::quit ();
@@ -72,7 +74,7 @@ bool GUI::MainWin::check_save ()
     }
     
     int   response;
-    int   time_since_save = time (0) - ResourceManager::get_modification_time ();
+    int   time_since_save = time (0) - manager->get_modification_time ();
     char *filename_message;
 
     if (filename != "")
@@ -115,7 +117,7 @@ bool GUI::MainWin::check_save ()
     if (response == save_btn)
     {
 	save_cb ();
-	if (ResourceManager::is_dirty ())
+	if (manager->is_dirty ())
 	    return check_save ();
     }
 	    
@@ -128,11 +130,7 @@ void GUI::MainWin::new_cb ()
     if (!check_save ())
 	return;
 
-    ResourceManager::reset ();
-    filename = "";
-    Guikachu::Main::instance ()->set_filename (filename);
-
-    update_title ();
+    Guikachu::Main::instance ()->new_doc ();
 }
 
 void GUI::MainWin::set_filename (const string& filename_)
@@ -153,7 +151,7 @@ void GUI::MainWin::save_cb ()
 	save_as_cb ();
     else
     {
-	ResourceManager::save (filename);
+	Guikachu::Main::instance ()->save_doc (filename);
 	if (in_exit)
 	    Gnome::Main::quit ();
     }
@@ -233,8 +231,11 @@ void GUI::MainWin::export_cb ()
     Gtk::Main::run ();
 }
 
-void GUI::MainWin::open (std::string new_filename)
+void GUI::MainWin::open (std::string filename)
 {
+    Guikachu::Main::instance ()->load_doc (filename);
+    
+#if 0
     ResourceManager::IOResult result = ResourceManager::load (new_filename);
 
     gchar *buffer;
@@ -259,6 +260,7 @@ void GUI::MainWin::open (std::string new_filename)
 	g_free (buffer);
 	break;
     }
+#endif
 }
 
 /*********************************
@@ -268,9 +270,7 @@ void GUI::MainWin::filesel_save_cb (Gtk::FileSelection *fs)
 {
     filename = fs->get_filename ();
     filesel_close_cb (fs);
-    Guikachu::Main::instance ()->set_filename (filename);
 
-    update_title ();
     save_cb ();
 
     if (in_exit)
@@ -289,8 +289,10 @@ void GUI::MainWin::filesel_export_cb (Gtk::FileSelection *fs)
 {
     string filename = fs->get_filename ();
     filesel_close_cb (fs);
-    
-    ResourceManager::export_rcp (filename);
+
+    IO::Saver *rcp_saver = new IO::RCPSaver;
+    rcp_saver->save (manager, filename);
+    delete rcp_saver;
 }
 
 int GUI::MainWin::delete_event_impl (GdkEventAny *e)
