@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.28.2.1 2002/05/25 13:34:47 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.33 2002/06/30 19:54:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -37,6 +37,7 @@
 #include "add-resource.h"
 #include "preferences-win.h"
 #include "preferences.h"
+#include "session.h"
 
 #include <fstream>
 #include <sigc++/rettype.h>
@@ -46,8 +47,11 @@ using namespace Guikachu;
 
 GUI::MainWin::MainWin ():
     Gnome::App ("Guikachu", "Guikachu"),
+    manager (0),
+    top_item (0),
     filename (""),
-    in_exit (false)
+    in_exit (false),
+    recent_files_num (0)   
 {
     using namespace SigC;
     
@@ -125,25 +129,40 @@ GUI::MainWin::MainWin ():
 	slot (this, &MainWin::update_recent_files));
     update_recent_files ();
     
-    
-    // Create the tree for the resources
     top_tree = new Gtk::Tree ();
-    main_tree = new Gtk::Tree ();
-    top_item = new TopTreeItem (ResourceManager::get_application ());
-    top_item->show ();
-    top_tree->tree ().push_back (*manage (top_item));
-    top_item->set_subtree (*manage (main_tree));
-    top_item->expand ();    
-
+    
     // Scrollable viewport
     Gtk::ScrolledWindow *scrollwin = new Gtk::ScrolledWindow ();
     scrollwin->set_policy (GTK_POLICY_AUTOMATIC,
 			   GTK_POLICY_AUTOMATIC);
     scrollwin->add_with_viewport (*manage (top_tree));
+    scrollwin->show_all ();
     set_contents (*manage (scrollwin));
     set_usize (300, 250);
 
-    /* Create subtrees */
+    /* Connect to window events */
+    key_press_event.connect (retbind (slot (this, &MainWin::key_press_cb), 1));
+
+    update_title ();
+}
+
+void GUI::MainWin::set_manager (ResourceManager *manager_)
+{
+    manager = manager_;
+
+    // Top treeitem
+    top_tree->tree ().clear ();
+    top_item = new TopTreeItem (manager->get_application ());    
+    top_item->show ();
+    top_tree->tree ().push_back (*manage (top_item));
+
+    // Create the tree for the resources
+    main_tree = new Gtk::Tree ();
+    top_item->set_subtree (*manage (main_tree));
+    top_item->expand ();
+
+    // Create subtrees
+    subtrees.clear ();
     create_tree_for_type (Resources::RESOURCE_DIALOG,     _("Dialogs"));
     create_tree_for_type (Resources::RESOURCE_FORM,       _("Forms"));
     create_tree_for_type (Resources::RESOURCE_MENU,       _("Menus"));
@@ -152,19 +171,14 @@ GUI::MainWin::MainWin ():
     create_tree_for_type (Resources::RESOURCE_BLOB,       _("Blobs"));
 
     /* Fill with existing resources */
-    std::set<Resource*> resources = ResourceManager::get_resources ();
+    std::set<Resource*> resources = manager->get_resources ();
     for (std::set<Resource*>::iterator i = resources.begin ();
 	 i != resources.end (); i++)
 	resource_created_cb ((*i));
-    
-    /* Connect to Resource Manager signals */
-    ResourceManager::resource_created.connect (slot (this, &MainWin::resource_created_cb));
-    ResourceManager::resource_removed.connect (slot (this, &MainWin::resource_removed_cb));
 
-    /* Connect to window events */
-    key_press_event.connect (retbind (slot (this, &MainWin::key_press_cb), 1));
-    
-    update_title ();
+    /* Connect to Resource Manager signals */
+    manager->resource_created.connect (slot (this, &MainWin::resource_created_cb));
+    manager->resource_removed.connect (slot (this, &MainWin::resource_removed_cb));
 }
 
 void GUI::MainWin::update_recent_files ()
@@ -269,7 +283,7 @@ void GUI::MainWin::create_tree_for_type (Resources::Type    type,
 
 void GUI::MainWin::add_cb ()
 {
-    static AddResourceWin add_win;
+    AddResourceWin add_win (manager);
 
     add_win.run ();
 }
@@ -310,7 +324,7 @@ void GUI::MainWin::key_press_cb (GdkEventKey *e)
 	    // If the per-app resource is selected, reset it
 	    if (dynamic_cast<GUI::TopTreeItem*> (*i))
 	    {
-		ResourceManager::get_application ()->reset ();
+		manager->get_application ()->reset ();
 		continue;
 	    }
 	    
@@ -318,7 +332,7 @@ void GUI::MainWin::key_press_cb (GdkEventKey *e)
 	    Resource *res = dynamic_cast<Resource*> (user_data);
 
 	    if (res)
-		ResourceManager::remove_resource (res);
+		manager->remove_resource (res);
 	}
     }
 }
@@ -355,15 +369,28 @@ void GUI::show_about ()
     about->run ();  
 }
 
-void GUI::show_error (const std::string &message)
+void GUI::show_error (const std::string &full_message,
+		      const std::string &short_message)
 {
-    Gnome::Dialog *dialog = Gnome::Dialogs::error (message);
-    dialog->run ();  
+    if (Guikachu::Main::initialized ())
+    {
+	Gnome::Dialog *dialog = Gnome::Dialogs::error (full_message);
+	dialog->run ();
+    } else {
+	if (short_message != "")
+	    std::cerr << _("Guikachu: Error: ") << short_message << std::endl;
+    }
 }
 
-void GUI::show_warning (const std::string &message)
+void GUI::show_warning (const std::string &full_message,
+			const std::string &short_message)
 {
-    Gnome::Dialog *dialog = Gnome::Dialogs::warning (message);
-    dialog->run ();  
+    if (Guikachu::Main::initialized ())
+    {
+	Gnome::Dialog *dialog = Gnome::Dialogs::warning (full_message);
+	dialog->run ();
+    } else {
+	if (short_message != "")
+	    std::cerr << _("Guikachu: Warning: ") << short_message << std::endl;
+    }
 }
-
