@@ -1,4 +1,4 @@
-//$Id: mainwin.h,v 1.10.2.1 2002/05/25 13:34:47 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.h,v 1.14 2002/06/23 15:45:29 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,6 +33,7 @@ namespace Guikachu
 #include <gtk--/fileselection.h>
 #include <map>
 #include "resource.h"
+#include "resource-manager.h"
 
 namespace Guikachu
 {
@@ -43,6 +44,8 @@ namespace Guikachu
 	    typedef std::map<Resources::Type, Gtk::TreeItem*>     subtree_map;
 	    typedef std::map<Resource*, Guikachu::GUI::TreeItem*> treeitem_map;
 
+	    ResourceManager *manager;
+	    
 	    Gtk::Tree     *top_tree;
 	    Gtk::Tree     *main_tree;
 	    Gtk::TreeItem *top_item;
@@ -57,6 +60,7 @@ namespace Guikachu
 	public:
 	    MainWin ();
 	    void set_filename (const std::string& filename);
+	    void set_manager  (ResourceManager *manager);
 	    
 	private:
 	    void update_recent_files ();
@@ -93,8 +97,10 @@ namespace Guikachu
 	std::string visible_filename (const std::string &filename);
 	
 	void show_about ();
-	void show_error (const std::string   &message);
-	void show_warning (const std::string &message);
+	void show_error   (const std::string &full_message,
+			   const std::string &short_message = "");
+	void show_warning (const std::string &full_message,
+			   const std::string &short_message = "");
     }
 }
 
