@@ -1,4 +1,4 @@
-//$Id: property.h,v 1.13 2002/05/12 13:07:40 cactus Exp $ -*- c++ -*-
+//$Id: property.h,v 1.15 2002/06/22 13:03:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,7 +19,7 @@
 #ifndef GUIKACHU_PROPERTY_H
 #define GUIKACHU_PROPERTY_H
 
-#include <sigc++/basic_signal.h>
+#include "vsignal.h"
 #include <string>
 #include <iostream>
 
@@ -29,10 +29,10 @@ namespace Guikachu
     class Property
     {
     protected:
-	typedef T                   value_t;
-	typedef Property<T>         self_t;
+	typedef T           value_t;
+	typedef Property<T> self_t;
     
-	typedef SigC::Signal0<void> notify_signal_t;
+	typedef VSignal     notify_signal_t;
 
     public:
 	notify_signal_t &changed;
@@ -42,7 +42,7 @@ namespace Guikachu
 	
     public:
 	Property (notify_signal_t &notify_signal,
-		  const value_t   &value_ = 0):
+		  const value_t   &value_ = value_t ()):
 	    changed (notify_signal),
 	    value (value_)
 	    {
@@ -96,14 +96,17 @@ namespace Guikachu
     template<>
     void Property<std::string>::set_val (const std::string &value);
 
-
-    
     // Special property subclasses
     
+    class ResourceManager; // Forward declaration
+    
     class ID: public Property<std::string>
     {
+	ResourceManager *owner;
+	
     public:
 	ID (notify_signal_t   &notify_signal,
+	    ResourceManager   *owner,
 	    const std::string &value);
 	
 	inline const std::string& operator= (const std::string &value_) {
