@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.30.2.1 2002/05/29 16:02:26 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.34 2002/06/20 21:35:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,6 +18,8 @@
 
 #include "resource-manager.h"
 
+#include "config.h"
+
 #include "mainwin.h"
 #include "resource-util.h"
 
@@ -65,16 +67,21 @@ bool NoCase::operator () (const std::string &x, const std::string &y) const
     return (compare (x, y) < 0);
 }
 
-ResourceManager::resource_map_t  ResourceManager::resource_map;
-ResourceManager::id_set_t        ResourceManager::id_set;
-Resources::Application          *ResourceManager::app = 0;
-Target                          *ResourceManager::target = 0;
-bool                             ResourceManager::dirty = false;
-time_t                           ResourceManager::modification_time = 0;
-bool                             ResourceManager::encoding_fixed = false;
+ResourceManager::ResourceManager ():
+    app (this)
+{
+    app.changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
+    target.changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 
-SigC::Signal1<void, Resource*> ResourceManager::resource_created;
-SigC::Signal1<void, Resource*> ResourceManager::resource_removed;
+    clear_dirty ();
+}
+
+ResourceManager::~ResourceManager ()
+{
+    for (resource_map_t::iterator i = resource_map.begin ();
+	 i != resource_map.end ();)
+	remove_resource ((i++)->second);
+}
 
 std::string ResourceManager::create_id (const std::string &prefix)
 {
@@ -159,30 +166,30 @@ Resource* ResourceManager::create_resource (Resources::Type type,
     switch (type)
     {
     case Resources::RESOURCE_DIALOG:
-	res = new Resources::Dialog (real_id);
+	res = new Resources::Dialog (this, real_id);
 	break;
     case Resources::RESOURCE_STRING:
-	res = new Resources::String (real_id);
+	res = new Resources::String (this, real_id);
 	break;
     case Resources::RESOURCE_STRINGLIST:
-	res = new Resources::StringList (real_id);
+	res = new Resources::StringList (this, real_id);
 	break;
     case Resources::RESOURCE_BLOB:
-	res = new Resources::Blob (real_id);
+	res = new Resources::Blob (this, real_id);
 	break;
     case Resources::RESOURCE_MENU:
-	res = new Resources::Menu (real_id);
+	res = new Resources::Menu (this, real_id);
 	break;
     case Resources::RESOURCE_FORM:
-	Resources::Form *form = new Resources::Form (real_id);
-	form->widget_changed.connect (SigC::slot (&ResourceManager::set_dirty));
+	Resources::Form *form = new Resources::Form (this, real_id);
+	form->widget_changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 	res = form;
 	break;
     }
     
     resource_map.insert (std::make_pair (real_id, res));
 
-    res->changed.connect (SigC::slot (&ResourceManager::set_dirty));
+    res->changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 
     set_dirty ();
     
@@ -222,12 +229,12 @@ bool ResourceManager::rename_resource (const std::string &old_id,
     id_set.erase (old_id);
     id_set.insert (new_id);
 
-    resource_map_t::iterator map_i = resource_map.find (old_id);
+    resource_map_t::iterator old_entry = resource_map.find (old_id);
     
-    if (map_i != resource_map.end ())
+    if (old_entry != resource_map.end ())
     {
-	Resource *res = map_i->second;
-	resource_map.erase (map_i);
+	Resource *res = old_entry->second;
+	resource_map.erase (old_entry);
 	resource_map.insert (std::make_pair (new_id, res));
     }
 
@@ -246,7 +253,7 @@ void ResourceManager::remove_resource (Resource* resource)
     set_dirty ();
 }
 
-std::set<Resource*> ResourceManager::get_resources ()
+std::set<Resource*> ResourceManager::get_resources () const
 {
     std::set<Resource*> ret;
 
@@ -259,7 +266,7 @@ std::set<Resource*> ResourceManager::get_resources ()
     return ret;
 }
 
-Resource* ResourceManager::get_resource (const std::string &id)
+Resource* ResourceManager::get_resource (const std::string &id) const
 {
     resource_map_t::const_iterator found = resource_map.find (id);
 
