@@ -1,4 +1,4 @@
-//$Id: resource.cc,v 1.9 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: resource.cc,v 1.11 2002/06/08 14:28:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,16 +19,10 @@
 #include "resource.h"
 
 using namespace Guikachu;
-using std::string;
-using std::ostream;
 
-Resource::Resource (const string& id_):
-    id (changed, id_)
+Resource::Resource (ResourceManager   *owner_,
+		    const std::string &id_):
+    owner (owner_),
+    id (changed, owner, id_)
 {
 }
-
-ostream& Guikachu::operator<< (ostream &ostr, const Resource* res)
-{
-    res->save_rcp (ostr);
-    return ostr;
-}
