@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.19 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.26 2002/06/22 13:03:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,8 +20,6 @@
 #define GUIKACHU_RESOURCE_H
 
 #include <string>
-#include <iostream>
-#include <sigc++/basic_signal.h>
 
 namespace Guikachu
 {
@@ -41,40 +39,37 @@ namespace Guikachu
     class Resource;
 }
 
-#include "property.h"
-#include "storage-node.h"
+#include "queued-signal.h"
 #include "resource-manager.h"
+#include "property.h"
 
 namespace Guikachu
 {
     class Resource: public SigC::Object
     {
     protected:
-	Resource (const std::string& id);
+	Resource (ResourceManager   *owner,
+		  const std::string &id);
+
+	ResourceManager *owner;
 	
     public:
 	virtual ~Resource () {};
+
+	ResourceManager * get_manager () { return owner; };
 	
 	// Resource managment functions
 	virtual Resources::Type get_type () const = 0;
 	
 	// Notification
-	SigC::Signal0<void> changed;
+	QueuedSignal changed;
 	
 	// Common properties
 	ID id;
 	
 	// User interface hook
 	virtual void show_ui () = 0;
-	
-    public:
-	// Persistance
-	virtual bool load (StorageNode &node) = 0;
-	virtual void save (StorageNode &node) const = 0;
-	virtual void save_rcp (std::ostream &ostr) const = 0;
-	};
-    
-    std::ostream& operator<< (std::ostream &ostr, const Resource* res);
+    };
 }
 
 #endif /* !GUIKACHU_RESOURCE_H */
