@@ -1,4 +1,4 @@
-//$Id: session.cc,v 1.7.2.1 2002/05/25 13:34:47 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.11 2002/06/30 19:54:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,11 +26,17 @@
 #include <gconf/gconf.h>
 
 #include "resource-manager.h"
+#include "mainwin.h"
 #include "preferences.h"
 
-Guikachu::Main* Guikachu::Main::instance_ = 0;
+#include "io/guikachu-load.h"
+#include "io/guikachu-save.h"
 
-Guikachu::Main::Main (int argc, char **argv):
+using namespace Guikachu;
+
+Main* Guikachu::Main::instance_ = 0;
+
+Main::Main (int argc, char **argv):
     Gnome::Main (PACKAGE, VERSION, argc, argv, NULL, 0, &ctx),
     cmd_self (argv[0])
 {
@@ -45,8 +51,6 @@ Guikachu::Main::Main (int argc, char **argv):
     gconf_init (argc, argv, 0);
     glade_gnome_init ();
     
-    Guikachu::ResourceManager::reset ();
-
     // Set up session managment stuff
     Gnome::Client* session_client = Gnome::Client::master_client ();
     if (session_client)
@@ -64,18 +68,59 @@ Guikachu::Main::Main (int argc, char **argv):
 
     // Load preferences
     Preferences::load ();
+
+    // Create initial document
+    doc = new ResourceManager;
+
+    // Create main window
+    mainwin = new GUI::MainWin;
+    mainwin->set_manager (doc);
+    mainwin->show ();
 }
 
 
-Guikachu::Main::~Main ()
+Main::~Main ()
 {
     // Save preferences
     Preferences::save ();
 }
 
-const std::vector<std::string>& Guikachu::Main::get_cmd_arguments ()
+void Main::new_doc ()
 {
-    return cmd_arguments;
+    delete doc;
+    doc = new ResourceManager;
+    
+    mainwin->set_manager  (doc);
+    mainwin->set_filename ("");
+}
+
+void Main::save_doc (const std::string &filename)
+{
+    IO::Saver *saver = new IO::GuikachuSaver;
+    if (saver->save (doc, filename) == IO::RESULT_OK)
+    {
+	doc->clear_dirty ();
+	set_filename (filename);
+    }
+}
+
+void Main::load_doc (const std::string &filename)
+{
+    ResourceManager *new_doc = new ResourceManager;
+
+    IO::Loader *loader = new IO::GuikachuLoader;
+    if (loader->load (new_doc, filename) == IO::RESULT_OK)
+    {
+	delete doc;
+	doc = new_doc;
+
+	while (events_pending ())
+	    iteration ();	
+	doc->clear_dirty ();
+	
+	mainwin->set_manager  (doc);
+	set_filename (filename);	
+    }
 }
 
 void Guikachu::Main::session_die_cb ()
@@ -118,4 +163,5 @@ void Guikachu::Main::set_filename (const std::string &filename)
 	Preferences::Interface::add_recent_file (filename);
     
     last_filename = filename;
+    mainwin->set_filename (filename);
 }
