@@ -1,4 +1,4 @@
-//$Id: storage-node.cc,v 1.10.2.2 2002/05/29 16:02:26 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.cc,v 1.19 2002/06/23 15:45:29 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,24 +18,37 @@
 
 #include "storage-node.h"
 
-#include "property.h"
-
+#include "config.h"
 #include <gnome-xml/xmlmemory.h>
 #include <glib.h>
-#include <libgnome/libgnome.h>
+#include <libgnome/libgnome.h> // for gnome_i18n_get_language_list
 
-#include "resource-manager.h"
+#include "storage.h"
 
 using namespace Guikachu;
 
-StorageNode::StorageNode ():
-    node_ptr (0)
-{
+StorageNode::StorageNode (xmlNodePtr node, Storage *parent_doc_):
+    node_ptr (node),
+    parent_doc (parent_doc_)
+{   
 }
 
-StorageNode::StorageNode (xmlNodePtr root):
-    node_ptr (root)
-{   
+StorageNode StorageNode::children () const
+{
+    return StorageNode (node_ptr->xmlChildrenNode, parent_doc);
+}
+
+StorageNode StorageNode::operator++ (int)
+{
+    StorageNode tmp = *this;
+    node_ptr = next ().c_node ();
+    return tmp;
+}
+
+StorageNode& StorageNode::operator++ ()
+{
+    node_ptr = next ().c_node ();
+    return *this;
 }
 
 std::string StorageNode::name () const
@@ -49,7 +62,7 @@ std::string StorageNode::name () const
 StorageNode StorageNode::add_node (const std::string &name,
 				   const std::string &content)
 {
-    g_return_val_if_fail (node_ptr != 0, 0);
+    g_assert (node_ptr != 0);
     
     xmlNodePtr new_node_ptr = 0;
 
@@ -61,19 +74,19 @@ StorageNode StorageNode::add_node (const std::string &name,
 	new_node_ptr = xmlNewChild (node_ptr, 0,
 				    (xmlChar*)name.c_str (), 0);
 
-    return StorageNode (new_node_ptr);
+    return StorageNode (new_node_ptr, parent_doc);
 }
 
 void StorageNode::set_content (const std::string &content)
 {
-    g_return_if_fail (node_ptr != 0);
+    g_assert (node_ptr != 0);
 
     xmlNodeSetContent (node_ptr, (xmlChar*) content.c_str ());
 }
 
-std::string StorageNode::get_raw_content () const
+std::string StorageNode::get_content_raw () const
 {
-    g_return_val_if_fail (node_ptr != 0, 0);
+    g_assert (node_ptr != 0);
     
     std::string ret;
     char *tmp = (char*)xmlNodeGetContent (node_ptr);
@@ -88,39 +101,49 @@ std::string StorageNode::get_raw_content () const
     return ret;
 }
 
+namespace
+{
+    bool escape_string (std::string &raw_str)
+    {
+	std::string converted_str;
+	bool converted = false;
+	
+	for (std::string::const_iterator i = raw_str.begin (); i != raw_str.end (); ++i)
+	{
+	    if (*i < 0)
+	    {
+		converted = true;
+		
+		char *tmp = g_strdup_printf ("\\x%X", (unsigned char)*i);
+		converted_str += tmp;
+		g_free (tmp);
+	    } else {
+		converted_str += *i;
+	    }
+	}
+
+	if (converted)
+	    raw_str = converted_str;
+
+	return converted;
+    }
+}
+
 std::string StorageNode::get_content () const
 {
-    std::string ret_raw = get_raw_content ();
-    bool converted = false;
+    std::string ret_val = get_content_raw ();
 
-    // Convert non-ASCII characters to escape sequences
-    std::string ret;
-    for (std::string::const_iterator i = ret_raw.begin ();
-	 i != ret_raw.end (); i++)
-    {
-	if (*i < 0)
-	{
-	    converted = true;
-	    
-	    char *tmp = g_strdup_printf ("\\x%X", (unsigned char)*i);
-	    ret += tmp;
-	    g_free (tmp);
-	} else {
-	    ret += *i;
-	}
-    }
-
-    if (converted)
-	ResourceManager::encoding_fixed_cb ();
-
-    return ret;
+    if (escape_string (ret_val))
+	parent_doc->encoding_notify.emit ();
+    
+    return ret_val;
 }
 
 
 void StorageNode::set_prop (const std::string &prop_name,
 			    const std::string &value)
 {
-    g_return_if_fail (node_ptr != 0);
+    g_assert (node_ptr != 0);
 
     xmlSetProp (node_ptr,
 		(xmlChar*) prop_name.c_str (),
@@ -130,7 +153,7 @@ void StorageNode::set_prop (const std::string &prop_name,
 void StorageNode::set_prop (const std::string &prop_name,
 			    unsigned int       value)
 {
-    g_return_if_fail (node_ptr != 0);
+    g_assert (node_ptr != 0);
 
     char *tmp = g_strdup_printf ("%d", value);
     set_prop (prop_name, tmp);
@@ -140,8 +163,8 @@ void StorageNode::set_prop (const std::string &prop_name,
 void StorageNode::set_prop (const std::string &prop_name,
 			    int                value)
 {
-    g_return_if_fail (node_ptr != 0);
-
+    g_assert (node_ptr != 0);
+    
     char *tmp = g_strdup_printf ("%d", value);
     set_prop (prop_name, tmp);
     g_free (tmp);
@@ -150,7 +173,7 @@ void StorageNode::set_prop (const std::string &prop_name,
 void StorageNode::set_prop (const std::string &prop_name,
 			    char               value)
 {
-    g_return_if_fail (node_ptr != 0);
+    g_assert (node_ptr != 0);
 
     if (!value)
 	return;
@@ -161,10 +184,9 @@ void StorageNode::set_prop (const std::string &prop_name,
     set_prop (prop_name, buffer);
 }
 
-template <>
-std::string StorageNode::get_prop <std::string> (const std::string &prop_name) const
+std::string StorageNode::get_prop_string_raw (const std::string &prop_name) const
 {
-    g_return_val_if_fail (node_ptr != 0, 0);
+    g_assert (node_ptr != 0);
 
     std::string ret;
     
@@ -174,17 +196,24 @@ std::string StorageNode::get_prop <std::string> (const std::string &prop_name) c
     {
 	ret = (char*) xml_tmp;
 	xmlFree (xml_tmp);
-    } else {
-	ret = "";
     }
-
+    
     return ret;
 }
 
-template <>
-int StorageNode::get_prop <int> (const std::string &prop_name) const
+std::string StorageNode::get_prop_string (const std::string &prop_name) const
 {
-    g_return_val_if_fail (node_ptr != 0, 0);
+    std::string ret_val = get_prop_string_raw (prop_name);
+    
+    if (escape_string (ret_val))
+	parent_doc->encoding_notify.emit ();
+    
+    return ret_val;
+}
+
+int StorageNode::get_prop_int (const std::string &prop_name) const
+{
+    g_assert (node_ptr != 0);
 
     int ret;
 
@@ -200,10 +229,9 @@ int StorageNode::get_prop <int> (const std::string &prop_name) const
     return ret;
 }
 
-template <>
-char StorageNode::get_prop <char> (const std::string &prop_name) const
+char StorageNode::get_prop_char (const std::string &prop_name) const
 {
-    g_return_val_if_fail (node_ptr != 0, 0);
+    g_assert (node_ptr != 0);
 
     char ret = 0;
 
@@ -221,21 +249,20 @@ char StorageNode::get_prop <char> (const std::string &prop_name) const
 
 StorageNode StorageNode::next () const
 {
-    return node_ptr->next;
+    return StorageNode (node_ptr->next, parent_doc);
 }
 
 StorageNode StorageNode::get_translated_child (const std::string &name) const
 {
     // This one is lifted from GAL. It's pretty smart, actually.
     
-    StorageNode best_node;
-    StorageNode node;
+    StorageNode best_node (0, parent_doc);
 
     GList *lang_list = gnome_i18n_get_language_list ("LC_MESSAGES");
     
     int best_score = INT_MAX;
     
-    for (node = children (); node; node++)
+    for (StorageNode node = children (); node; node++)
     {
 	if (node.name () != name)
 	    continue;
