@@ -1,4 +1,4 @@
-//$Id: storage-node.h,v 1.9.2.1 2002/05/25 14:21:58 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.h,v 1.13 2002/06/19 16:08:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,13 +25,19 @@
 
 namespace Guikachu
 {
+    class Storage;
+    
     class StorageNode
     {
-	xmlNodePtr node_ptr;
-    public:
-	StorageNode ();
-	StorageNode (xmlNodePtr root);
+	xmlNodePtr  node_ptr;
+	Storage    *parent_doc;
 
+	friend class Storage;
+
+	StorageNode ();
+	StorageNode (xmlNodePtr node, Storage *parent_doc);
+
+    public:
 	std::string name () const;
 	inline xmlNodePtr c_node () const { return node_ptr; };
 	
@@ -39,18 +45,19 @@ namespace Guikachu
 	StorageNode add_node (const std::string &name,
 			      const std::string &content = "");
 
-	StorageNode children () const { return node_ptr->xmlChildrenNode; };
-	StorageNode next ()     const;
-	StorageNode &operator++ (int) { node_ptr = next ().c_node (); return *this; };
+	StorageNode  children () const;
+	StorageNode  next ()     const;
+	StorageNode  operator++ (int);
+	StorageNode &operator++ ();
 
 	StorageNode get_translated_child (const std::string &name) const;
 	
 	inline operator bool () { return node_ptr != 0; }
-	
+
 	/* Content management */
-	void        set_content (const std::string& content);
-	std::string get_content () const;
-	std::string get_raw_content () const;
+	void        set_content     (const std::string& content);
+	std::string get_content     () const;
+	std::string get_content_raw () const;
 
 	/* Property manipulation */
 	template<class T> void set_prop (const std::string &prop_name,
@@ -60,7 +67,10 @@ namespace Guikachu
 	void set_prop (const std::string &prop_name, unsigned int value);
 	void set_prop (const std::string &prop_name, char value);
 
-	template<class T> T get_prop (const std::string &prop_name) const;
+	int         get_prop_int        (const std::string &prop_name) const;
+	std::string get_prop_string     (const std::string &prop_name) const;
+	std::string get_prop_string_raw (const std::string &prop_name) const;
+	char        get_prop_char       (const std::string &prop_name) const;
     };
 
     template<class T>
