@@ -1,4 +1,4 @@
-//$Id: storage.cc,v 1.3 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: storage.cc,v 1.4 2002/06/07 23:40:18 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -53,26 +53,26 @@ void Storage::save (const std::string &filename) const
     xmlSaveFile (filename.c_str (), doc);
 }
 
-StorageNode Storage::get_root () const
+StorageNode Storage::get_root ()
 {
-    g_return_val_if_fail (doc != 0, 0);
+    g_assert (doc != 0);
     
-    return StorageNode (xmlDocGetRootElement (doc));
+    return StorageNode (xmlDocGetRootElement (doc), this);
 }
 
 void Storage::set_root (StorageNode &node)
 {
-    g_return_if_fail (doc != 0);
+    g_assert (doc != 0);
     
     xmlDocSetRootElement (doc, node.c_node ());
 }
 
 StorageNode Storage::create_root (const std::string &name)
 {
-    g_return_val_if_fail (doc != 0, 0);
+    g_assert (doc != 0);
     
     xmlNodePtr root_node = xmlNewNode (NULL, (xmlChar*) name.c_str ());
     xmlDocSetRootElement (doc, root_node);
 
-    return StorageNode (root_node);
+    return StorageNode (root_node, this);
 }
