@@ -1,4 +1,4 @@
-//$Id: storage.h,v 1.3 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.5 2002/06/11 17:51:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,8 @@
 #define GUIKACHU_STORAGE_H
 
 #include <string>
+#include <sigc++/basic_signal.h>
+
 #include "storage-node.h"
 
 namespace Guikachu
@@ -27,6 +29,7 @@ namespace Guikachu
     class Storage
     {
 	xmlDocPtr doc;
+	
     public:
 	Storage ();
 	~Storage ();
@@ -34,9 +37,11 @@ namespace Guikachu
 	bool load (const std::string &filename);
 	void save (const std::string &filename) const;
 	
-	StorageNode get_root    () const;
+	StorageNode get_root    ();
 	void        set_root    (StorageNode &root);
 	StorageNode create_root (const std::string &name);
+
+	SigC::Signal0<void> encoding_notify;
     };
 };
 
