@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.11 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.14 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,18 +42,14 @@ namespace Guikachu
 	{
 	    GUI::StringWindow *gui;
 	public:
-	    String (const std::string& id);
+	    String (ResourceManager   *owner,
+		    const std::string &id);
 	    virtual ~String ();
 
 	    virtual Type get_type () const { return RESOURCE_STRING; };
 	    virtual void show_ui ();
 
 	    Property<std::string> text;
-
-	private:
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
