@@ -1,4 +1,4 @@
-//$Id: stringlist-res.h,v 1.2 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: stringlist-res.h,v 1.5 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,7 +43,8 @@ namespace Guikachu
 	{
 	    GUI::StringListWindow *gui;
 	public:
-	    StringList (const std::string &id);
+	    StringList (ResourceManager   *owner,
+			const std::string &id);
 	    virtual ~StringList ();
 
 	    virtual Type get_type () const { return RESOURCE_STRINGLIST; };
@@ -51,11 +52,6 @@ namespace Guikachu
 
 	    Property<std::string>                prefix;
 	    Property<std::vector <std::string> > strings;
-
-	private:
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
