@@ -1,4 +1,4 @@
-//$Id: target.h,v 1.3 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: target.h,v 1.6 2002/06/22 13:03:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,7 +24,6 @@
 #include <sigc++/object.h>
 
 #include "property.h"
-#include "storage-node.h"
 
 namespace Guikachu
 {
@@ -41,16 +40,12 @@ namespace Guikachu
 	static std::map<std::string, std::string> stock_targets ();
 	static std::string get_default_stock_id ();
 	
-	SigC::Signal0<void> changed;
+	VSignal changed;
 	
 	// Screen dimensions in pixels (used by the form editor
 	Property<int> screen_width;
 	Property<int> screen_height;
 
-	// Persistance
-	bool load (StorageNode &node);
-	void save (StorageNode &node) const;
-
     private:
 	void changed_cb ();
     };
