@@ -1,4 +1,4 @@
-//$Id: treeitem.cc,v 1.10 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.cc,v 1.11 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -88,7 +88,7 @@ void GUI::TreeItem::resource_changed_cb ()
 
 void GUI::TreeItem::menu_remove_cb ()
 {
-    ResourceManager::remove_resource (res);
+    res->get_manager ()->remove_resource (res);
 }
 
 void GUI::TreeItem::menu_edit_cb ()
