@@ -1,4 +1,4 @@
-//$Id: entry.cc,v 1.6 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: entry.cc,v 1.8 2002/06/29 21:10:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,8 @@ Entry::Entry (bool                   live_update,
 	      Property<std::string> &property_):
     PropertyEditor (this),
     property (property_),
-    update_block (false)
+    update_block (false),
+    cursor_pos (-1)
 {
     using namespace SigC;
     
@@ -51,13 +52,12 @@ void Entry::changed_cb ()
 
     update_block = true;
     
-    int saved_pos = get_position ();
+    cursor_pos = get_position ();
     property = get_text ();
 
     update_block = false;
     
     update ();
-    set_position (saved_pos);
 }
 
 void Entry::update ()
@@ -65,6 +65,8 @@ void Entry::update ()
     update_block = true;
 
     set_text (property);
+    if (cursor_pos >= 0)
+	set_position (cursor_pos + 1);
     
     update_block = false;
 }
