@@ -1,4 +1,4 @@
-//$Id: resource-combo.cc,v 1.9 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.cc,v 1.10 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,9 +26,11 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-ResourceCombo::ResourceCombo (Resources::Type          type_,
+ResourceCombo::ResourceCombo (ResourceManager         *manager_,
+			      Resources::Type          type_,
 			      Properties::ResourceRef &property_):
     Gtk::HBox (false, 5),
+    manager (manager_),
     button_edit (_("Edit...")),
     type (type_),
     property (property_)
@@ -38,7 +40,7 @@ ResourceCombo::ResourceCombo (Resources::Type          type_,
     combo.set_case_sensitive (false);
     combo.get_entry ()->set_editable (false);
     
-    std::set<Resource*> resource_set = ResourceManager::get_resources ();
+    std::set<Resource*> resource_set = manager->get_resources ();
 
     Gtk::ListItem *item = new Gtk::ListItem ("");
     item->set_user_data (0);
@@ -50,8 +52,8 @@ ResourceCombo::ResourceCombo (Resources::Type          type_,
 
     button_edit.clicked.connect (slot (this, &ResourceCombo::edit_cb));
     
-    ResourceManager::resource_created.connect (slot (this, &ResourceCombo::add_resource));
-    ResourceManager::resource_removed.connect (slot (this, &ResourceCombo::remove_resource));
+    manager->resource_created.connect (slot (this, &ResourceCombo::add_resource));
+    manager->resource_removed.connect (slot (this, &ResourceCombo::remove_resource));
     combo.get_entry ()->changed.connect (slot (this, &ResourceCombo::entry_cb));
     
     pack_start (combo);
@@ -113,7 +115,7 @@ void ResourceCombo::update ()
 
 void ResourceCombo::edit_cb ()
 {
-    Resource *res = ResourceManager::get_resource (property);
+    Resource *res = manager->get_resource (property);
     g_return_if_fail (res != 0);
     
     res->show_ui ();
