@@ -1,4 +1,4 @@
-//$Id: size-entry.cc,v 1.6 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: size-entry.cc,v 1.7 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,27 +23,29 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-WidthEntry::WidthEntry (Property<int> &property):
-    NumEntry (1, GUIKACHU_SCREEN_WIDTH, property)
+WidthEntry::WidthEntry (ResourceManager *manager,
+			Property<int>   &property):
+    NumEntry (1, manager->get_target ()->screen_width, property),
+    target (manager->get_target ())
 {
-    ResourceManager::get_target ()->changed.connect (
-	SigC::slot (this, &WidthEntry::target_changed_cb));
+    target->changed.connect (SigC::slot (this, &WidthEntry::target_changed_cb));
 }
 
 void WidthEntry::target_changed_cb ()
 {
-    get_adjustment ()->set_upper (GUIKACHU_SCREEN_WIDTH);
+    set_max (target->screen_width);
 }
 
-HeightEntry::HeightEntry (Property<int> &property):
-    NumEntry (1, GUIKACHU_SCREEN_HEIGHT, property)
+HeightEntry::HeightEntry (ResourceManager *manager,
+			  Property<int>   &property):
+    NumEntry (1, manager->get_target ()->screen_height, property),
+    target (manager->get_target ())
 {
-    ResourceManager::get_target ()->changed.connect (
-	SigC::slot (this, &HeightEntry::target_changed_cb));
+    target->changed.connect (SigC::slot (this, &HeightEntry::target_changed_cb));
 }
 
 void HeightEntry::target_changed_cb ()
 {
-    get_adjustment ()->set_upper (GUIKACHU_SCREEN_HEIGHT);
+    set_max (target->screen_height);
 }
 
