@@ -1,4 +1,4 @@
-//$Id: target-combo.h,v 1.3 2002/01/03 17:19:35 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.h,v 1.4 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include <gtk--/optionmenu.h>
 #include "property-editor.h"
+#include "resource-manager.h"
 #include <map>
 
 namespace Guikachu
@@ -32,10 +33,12 @@ namespace Guikachu
 	    class TargetCombo: public PropertyEditor,
 			       public Gtk::OptionMenu
 	    {
+		Target *target;
+		
 		std::map<std::string, int> stock_target_to_menuitem;
 		int                        num_targets;
 	    public:
-		TargetCombo ();
+		TargetCombo (ResourceManager *manager);
 
 		SigC::Signal0<void> custom_selected;
 		SigC::Signal0<void> stock_selected;
