@@ -1,4 +1,4 @@
-//$Id: text.cc,v 1.5 2002/01/01 21:23:43 cactus Exp $ -*- c++ -*-
+//$Id: text.cc,v 1.7 2002/06/29 21:10:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,7 +23,8 @@ using namespace Guikachu::GUI::PropertyEditors;
 TextArea::TextArea (Property<std::string> &text_):
     PropertyEditor (this),
     text (text_),
-    update_block (false)
+    update_block (false),
+    cursor_pos (-1)
 {
     using SigC::slot;
     
@@ -41,14 +42,12 @@ void TextArea::changed_cb ()
     if (update_block)
         return;
 
-    int saved_pos = get_position ();
+    cursor_pos = get_position ();
 
     gchar *text_chars = gtk_editable_get_chars (
 	GTK_EDITABLE (gtkobj ()), 0, get_length ());
     text = text_chars;
     g_free (text_chars);
-    
-    gtk_editable_set_position (GTK_EDITABLE (gtkobj ()), saved_pos);
 }
 
 void TextArea::update ()
@@ -59,5 +58,8 @@ void TextArea::update ()
 	delete_text (0, get_length ());
     insert (text);
 
+    if (cursor_pos >= 0)
+	gtk_editable_set_position (GTK_EDITABLE (gtkobj ()), cursor_pos);
+
     update_block = false;
 }
